pub struct ContentFile {
pub include: String,
pub exclude: Option<Vec<String>>,
pub build_action: Option<BuildAction>,
pub copy_to_output: Option<bool>,
pub flatten: Option<bool>,
}Fields
include: StringThe location of the file or files to include, subject to exclusions specified by the exclude attribute. The path is relative to the contentFiles folder unless an absolute path is specified. The wildcard character * is allowed, and the double wildcard ** implies a recursive folder search.
exclude: Option<Vec<String>>A semicolon-delimited list of files or file patterns to exclude from the src location. The wildcard character * is allowed, and the double wildcard ** implies a recursive folder search.
build_action: Option<BuildAction>The build action to assign to the content item for MSBuild, such as Content, None, Embedded Resource, Compile, etc. The default is Compile.
copy_to_output: Option<bool>A Boolean indicating whether to copy content items to the build (or publish) output folder. The default is false.
flatten: Option<bool>A Boolean indicating whether to copy content items to a single folder in the build output (true), or to preserve the folder structure in the package (false). This flag only works when copyToOutput flag is set to true. The default is false.